@@ -44,11 +44,11 @@ G_BEGIN_DECLS
 #define LIBBRASERO_MEDIA_VERSION_MINOR						\
 	12
 #define LIBBRASERO_MEDIA_VERSION_MICRO						\
-	2
+	3
 #define LIBBRASERO_MEDIA_AGE							\
-	362
+	372
 #define LIBBRASERO_MEDIA_INSTALL							\
-	"/usr/local"
+	"/home/david/gnome"
 
 /**
  * To start and stop the library
