@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -714,6 +714,8 @@ nautilus_disc_burn_get_background_items (NautilusMenuProvider *provider,
         items = NULL;
 
         scheme = nautilus_file_info_get_uri_scheme (current_folder);
+        if (!scheme)
+                return NULL;
 
         if (strcmp (scheme, "burn") == 0) {
                 NautilusMenuItem *item;
