@@ -438,7 +438,6 @@ brasero_wodim_write_inf (BraseroWodim *wodim,
 			 GError **error)
 {
 	gint fd;
-	int isrc;
 	gint size;
         int errsv;
 	gchar *path;
@@ -514,9 +513,9 @@ brasero_wodim_write_inf (BraseroWodim *wodim,
 		goto error;
 
 	/* ISRC */
-	isrc = brasero_track_tag_lookup_int (BRASERO_TRACK (track), BRASERO_TRACK_STREAM_ISRC_TAG);
-	if (isrc > 0)
-		string = g_strdup_printf ("ISRC=\t%i\n", isrc);
+	info = brasero_track_tag_lookup_string (BRASERO_TRACK (track), BRASERO_TRACK_STREAM_ISRC_TAG);
+	if (info)
+		string = g_strdup_printf ("ISRC=\t%s\n", info);
 	else
 		string = g_strdup ("ISRC=\t\n");
 	size = strlen (string);
