@@ -40,7 +40,6 @@
 #include "brasero-sum-dialog.h"
 #include "brasero-eject-dialog.h"
 #include "brasero-project-manager.h"
-#include "brasero-xsession.h"
 #include "brasero-pref.h"
 
 #include "brasero-drive.h"
@@ -513,7 +512,10 @@ brasero_app_set_parent (BraseroApp *app,
 	BraseroAppPrivate *priv;
 
 	priv = BRASERO_APP_PRIVATE (app);
-	priv->parent = gdk_x11_window_foreign_new_for_display (gdk_display_get_default (), parent_xid);
+#ifdef GDK_WINDOWING_X11
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+		priv->parent = gdk_x11_window_foreign_new_for_display (gdk_display_get_default (), parent_xid);
+#endif
 }
 
 gboolean
@@ -2064,9 +2066,6 @@ brasero_app_init (BraseroApp *object)
 	priv->setting = brasero_setting_get_default ();
 	brasero_setting_load (priv->setting);
 
-	/* Connect to session */
-	brasero_session_connect (object);
-
 	g_set_application_name (_("Disc Burner"));
 	gtk_window_set_default_icon_name ("brasero");
 
@@ -2084,8 +2083,6 @@ brasero_app_finalize (GObject *object)
 	g_object_unref (priv->setting);
 	priv->setting = NULL;
 
-	brasero_session_disconnect (BRASERO_APP (object));
-
 	if (priv->saved_contents) {
 		g_free (priv->saved_contents);
 		priv->saved_contents = NULL;
