@@ -40,8 +40,6 @@
 #include <gst/gst.h>
 
 
-#include "eggsmclient.h"
-
 #include "brasero-burn-lib.h"
 #include "brasero-misc.h"
 
@@ -89,7 +87,6 @@ main (int argc, char **argv)
 					   GETTEXT_PACKAGE);
 	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 
-	g_option_context_add_group (context, egg_sm_client_get_option_group ());
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_add_group (context, brasero_media_get_option_group ());
 	g_option_context_add_group (context, brasero_burn_library_get_option_group ());
